#

##

##

##

##

    	fields

    	possibities

    		https://developer.mozilla.org/en-US/docs/Web/HTML/Element/dialog

    	open

    		import { append_field } from '@/apps/fields'
    		const { coordinate } = await append_field ({
    			label: "OPTIONS",
    			region: import ('@/parcels/physics/field.vue')
    		})

    		import { remove_field } from '@/apps/fields'
    		remove_field ({ the_coordinate: 1 })

    	structure
    		app (

    					// Terrain slot

    					// Name slot

    		)

    	possibilities

    		{ } each field is it's own vue, etc. app
    		{ } a field could open up an iframe for enhanced security...